==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QTreeWidgetItem_shell.h <==
#ifndef QTREEWIDGETITEM_SHELL_H
#define QTREEWIDGETITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(treewidget)
#include <QtWidgets/qtreewidget.h>
#endif //QT_CONFIG(treewidget)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qdatastream.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qsize.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qicon.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(treewidget)

class QTreeWidgetItem_shell : public QTreeWidgetItem, public QtJambiShellInterface
{
public:
    QTreeWidgetItem_shell(QTreeWidget* treeview0, QTreeWidgetItem* after1);
    QTreeWidgetItem_shell(QTreeWidget* treeview0, const QStringList& strings1);
    QTreeWidgetItem_shell(QTreeWidget* treeview0);
    QTreeWidgetItem_shell(QTreeWidgetItem* parent0, QTreeWidgetItem* after1);
    QTreeWidgetItem_shell(QTreeWidgetItem* parent0, const QStringList& strings1);
    QTreeWidgetItem_shell(QTreeWidgetItem* parent0);
    QTreeWidgetItem_shell(const QStringList& strings0);
    QTreeWidgetItem_shell();
    ~QTreeWidgetItem_shell() override;

    QTreeWidgetItem* clone() const override;
    QVariant data(int column0, int role1) const override;
    bool operator<(const QTreeWidgetItem& other0) const override;
    void read(QDataStream& in0) override;
    void setData(int column0, int role1, const QVariant& value2) override;
    void write(QDataStream& out0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTreeWidgetItem_access : public QTreeWidgetItem
{
    void __qt_emitDataChanged(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_data_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint role1) const;
    jboolean __qt_operator_less_cref_QTreeWidgetItem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const;
    void __qt_read_ref_QDataStream(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID in0);
    void __qt_setData_int_int_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint role1, jobject value2);
    void __qt_write_ref_QDataStream_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID out0) const;
};

#endif // QT_CONFIG(treewidget)
#endif // QTREEWIDGETITEM_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QTreeWidgetItem_shell.h <==
#ifndef QTREEWIDGETITEM_SHELL_H
#define QTREEWIDGETITEM_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(treewidget)
#include <QtWidgets/qtreewidget.h>
#endif //QT_CONFIG(treewidget)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qdatastream.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qsize.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qicon.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(treewidget)

class QTreeWidgetItem_shell : public QTreeWidgetItem, public QtJambiShellInterface
{
public:
    QTreeWidgetItem_shell(const QStringList& strings0);
    QTreeWidgetItem_shell(QTreeWidget* treeview0, const QStringList& strings1);
    QTreeWidgetItem_shell(QTreeWidget* treeview0, QTreeWidgetItem* after1);
    QTreeWidgetItem_shell(QTreeWidget* treeview0);
    QTreeWidgetItem_shell(QTreeWidgetItem* parent0, const QStringList& strings1);
    QTreeWidgetItem_shell(QTreeWidgetItem* parent0, QTreeWidgetItem* after1);
    QTreeWidgetItem_shell(QTreeWidgetItem* parent0);
    QTreeWidgetItem_shell();
    ~QTreeWidgetItem_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QTreeWidgetItem_oshell;
};


class QTreeWidgetItem_oshell : public QTreeWidgetItem_shell
{
public:
    using QTreeWidgetItem_shell::QTreeWidgetItem_shell;
    QTreeWidgetItem* clone() const override;
    QVariant data(int column0, int role1) const override;
    bool operator<(const QTreeWidgetItem& other0) const override;
    void read(QDataStream& in0) override;
    void setData(int column0, int role1, const QVariant& value2) override;
    void write(QDataStream& out0) const override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTreeWidgetItem_access : public QTreeWidgetItem
{
    void __qt_emitDataChanged(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_data_int_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint role1) const;
    jboolean __qt_operator_less_cref_QTreeWidgetItem_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0) const;
    void __qt_read_ref_QDataStream(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID in0);
    void __qt_setData_int_int_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint column0, jint role1, jobject value2);
    void __qt_write_ref_QDataStream_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID out0) const;
};

#endif // QT_CONFIG(treewidget)
#endif // QTREEWIDGETITEM_SHELL_H
